from setuptools import setup

setup(name='rj_distributions',
      version='0.0.1',
      description='Gaussian distributions',
      packages=['rj_distributions'],
      author='Rijul Paul',
      author_email='rijul90@gmail.com',
      zip_safe=False)
